@@ -4,7 +4,7 @@ import os, validators, collections, pathlib
 import mutagen
 from enum import Enum
 
-import .format_display import FormatUtils
+from .format_display import FormatUtils
 
 
 #options for downloading the youtube video
@@ -263,8 +263,21 @@ class DLUtils():
         ydl_opts['format'] = format
 
         #download the video
-        with youtube_dl.YoutubeDL(ydl_opts) as ydl:
-            ydl.download([video["link"]])
+        try:
+            with youtube_dl.YoutubeDL(ydl_opts) as ydl:
+                ydl.download([video["link"]])
+
+        # don't write the thumbnail if not possible
+        except:
+            ydl_opts.pop('writethumbnail')
+            ydl_opts["postprocessors"].pop()
+
+            with youtube_dl.YoutubeDL(ydl_opts) as ydl:
+                ydl.download([video["link"]])
+
+
+
+
 
         return cls.move_video(video_file_name, file_type, folder, video)
 
