@@ -1441,7 +1441,7 @@ def search_videos(search_query: str, no_of_searches: int):
 
 
 # run_main(): Runs the main app
-def run_main():
+def run_main(make_txt_setup: bool = True):
     if (root is not None):
         root.config(menu=menu_bar, bg="white")
 
@@ -1461,8 +1461,13 @@ if (__name__ != "__main__"):
         video_att_lsts[v] = video_att_frame_lsts[v]
 
 
+    # current file path of this file
+    file_path = os.path.realpath(__file__)
+    file_dir = os.path.dirname(file_path)
+
+
     #read the data from the setup file
-    setting_file = SetupFile("setup.txt", os.getcwd())
+    setting_file = SetupFile("setup.txt", file_dir)
     setting_data = setting_file.get_data()
 
     #create the root window for the app
@@ -1504,6 +1509,6 @@ if (__name__ != "__main__"):
 
     #icon photo
     try:
-        root.iconbitmap("icon.ico")
+        root.iconbitmap(f"{file_dir}\\icon.ico")
     except:
         pass
